# Model of the spectrum of surface waves


## Installation and usage
The installation itself is done by the pip package manager:

`pip install seawave-retracking`.

After that, copy the file `config.toml` from the repository into the current working directory and the program is ready to use. 
Basic usage can be found in the examples folder.


## References

<a id="1">[1]</a> Ryabkova M. Karaev V. , Guo J. , Titchenko Yu. 
A Review of Wave Spectrum Models as Applied to the Problem of Radar Probing of the Sea Surface, 
Journal of Geophysical Research: Oceans, 2019, pp. 7104–7134.

<a id="2">[2]</a> Panfilova M.A,  Karaev V.Yu. 
Evaluation of the boundary wave number for the two-scale model of backscatter of microwaves in Ka- and Ku-band by the sea surface using the Dual-frequency Precipitation Radar data, 2016,  Beijing, China.
